@@ -75,6 +75,8 @@ class Actor:
 
         if callable(step):
             self._step = step
+        elif step is None:
+            self._step = step
         else:
             self._step = round(step, 3)
 
@@ -87,7 +89,7 @@ class Actor:
 
         # initialize the status
         self._status = list()
-        if active:
+        if active and after is None:
             self.status.append("active")
         else:
             self.status.append("inactive")
@@ -100,7 +102,7 @@ class Actor:
 
     def perform(self):
         # non-continuous actor
-        if self.active:
+        if self.active and self.onhold is False:
             if self.step is None and self.till is None:
                 self.action()
                 self.status.append("completed")
@@ -138,15 +140,36 @@ class Actor:
         else:
             self.status.remove("active")
             self.status.append("inactive")
+            if self.time == self.till:
+                self.status.append("completed")
+            else:
+                self.status.append("onhold")        
+            for actor in self.followers:
+                if actor.onhold:
+                    actor.status.remove('onhold')
+                    # if actor.inactive:
+                    actor.status.remove('inactive')
+                    actor.status.append('active')
+                    actor._time = self.time
+                    self.timeline.schedule(actor)
 
-    def activate(self):
+    def activate(self, force: bool = True):
         if self.active:
             return
         else:
-            self.status.remove("inactive")
-            self.status.append("active")
-            self._time = self.timeline.now
-            self.timeline.schedule(self)
+            if force:
+                self.status.remove("inactive")
+                self.status.remove("onhold")
+                self.status.append("active")
+                self._time = self.timeline.now
+                self.timeline.schedule(self)
+            else:
+                if self.after.completed:
+                    self.status.remove("inactive")
+                    self.status.remove("onhold")
+                    self.status.append("active")
+                    self._time = self.timeline.now
+                    self.timeline.schedule(self)
 
     def request(self, resource: Resource, amount: Union[int, float] = 1) -> bool:
         resource.distribute(self, amount)
@@ -208,6 +231,10 @@ class Actor:
     def onhold(self):
         return "onhold" in self.status
 
+    @property
+    def scheduled(self):
+        return "scheduled" in self.status
+
     @property
     def completed(self):
         return "completed" in self.status
